@@ -82,7 +82,7 @@ const gchar *	camel_mapi_store_folder_lookup (CamelMapiStore *mapi_store, const
 const gchar *	camel_mapi_store_system_folder_fid (CamelMapiStore *mapi_store, guint folder_type);
 const gchar *	mapi_folders_hash_table_name_lookup (CamelMapiStore *store, const gchar *fid, gboolean use_cache);
 
-EMapiConnection *	camel_mapi_store_get_connection (CamelMapiStore *mapi_store,
+EMapiConnection *	camel_mapi_store_ref_connection (CamelMapiStore *mapi_store,
 							 GCancellable *cancellable,
 							 GError **error);
 
